@@ -107,6 +107,7 @@ from fnmatch import fnmatch
 from json import loads
 from os import getloadavg
 from pathlib import Path
+import re
 
 INVALID_CPU_TEMP_UNIT = "invalid cpu_temp_unit"
 STRING_NOT_INSTALLED = "not installed"
@@ -290,19 +291,23 @@ class Py3status:
                 args += "f"  # print fahrenheit
 
             chips_and_sensors = [
-                ("coretemp-isa-0000", "Core"),  # Intel
-                ("k10temp-pci-00c3", "Tdie"),  # AMD
-                ("cpu_thermal-virtual-0", "temp"),  # RPi
+                ("coretemp-isa-0000", ["Core"]),  # Intel
+                ("k10temp-pci-00c3", ["Tdie", "Tctl"]),  # AMD
+                ("cpu_thermal-virtual-0", ["temp"]),  # RPi
             ]
 
             chips = loads(self.py3.command_output([command, args]))
-            for chip, sensor in chips_and_sensors:
+            for chip, sensors in chips_and_sensors:
                 if chip in chips:
-                    self.lm_sensors = {
-                        "command": [command, args, chip],
-                        "chip": chip,
-                        "sensor": sensor,
-                    }
+                    for sensor in sensors:
+                        for temp_sensor in chips[chip]:
+                            if sensor in temp_sensor:
+                                self.lm_sensors = {
+                                    "command": [command, args, chip],
+                                    "chip": chip,
+                                    "sensor": sensor,
+                                }
+                                break
                     break
             else:
                 self.init["cpu_temp"] = []
@@ -361,12 +366,14 @@ class Py3status:
         of used memory, and units of mem (KiB, MiB, GiB).
         """
         if memory:
+            zfs_cache = self._get_zfs_arc_size()
             total_mem_kib = meminfo["MemTotal:"]
             used_mem_kib = (
                 total_mem_kib
                 - meminfo["MemFree:"]
                 - (
                     meminfo["Buffers:"]
+                    + zfs_cache
                     + meminfo["Cached:"]
                     + (meminfo["SReclaimable:"] - meminfo["Shmem:"])
                 )
@@ -404,6 +411,21 @@ class Py3status:
             info = [next(f).split() for _ in range(head)]
             return {fields[0]: float(fields[1]) for fields in info}
 
+    def _get_zfs_arc_size(self):
+        """will raise OSError on failures"""
+        ZFS_SIZE_REGEX = re.compile(r"^size\s+\d+\s+(\d+)")
+        try:
+            with Path("/proc/spl/kstat/zfs/arcstats").open() as f:
+                for line in f.readlines():
+                    m = ZFS_SIZE_REGEX.match(line)
+                    if m:
+                        return int(m.group(1)) / 1024
+        except (OSError, ValueError):
+            # skip errors if file is missing or inaccessible, or
+            # doesn't have the expected syntax
+            pass
+        return 0
+
     def _calc_cpu_percent(self, cpu):
         name, idle, total = cpu
         last_idle = self.cpus["last"].get(name, {}).get("idle", 0)
